#include "config.h"

#include <gtk/gtk.h>
#include <glib/gi18n.h>

#include "boilerplate-log.h"
#include "boilerplate-application.h"

static gboolean
verbose_cb (const gchar  *option_name,
            const gchar  *value,
            gpointer      data,
            GError      **error)
{
    boilerplate_log_increase_verbosity ();
    return TRUE;
}

static void
early_verbose_check (gint    *argc,
                     gchar ***argv)
{
    GOptionContext *context;
    static const GOptionEntry option_entries[] = {
        { "verbose", 'v', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, verbose_cb, "Show extra output", NULL },
        { NULL }
    };

    context = g_option_context_new (NULL);
    g_option_context_set_ignore_unknown_options (context, TRUE);
    g_option_context_set_help_enabled (context, FALSE);
    g_option_context_add_main_entries (context, option_entries, NULL);
    g_option_context_parse (context, argc, argv, NULL);
    g_option_context_free (context);
}

int
main (int    argc,
      char **argv)
{
    BoilerplateApplication *application;
    int status;

    boilerplate_log_init ();

    early_verbose_check (&argc, &argv);

    //TODO: Enable gettext ()
    /*
    bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
    textdomain (GETTEXT_PACKAGE);
    */
    g_set_prgname (PACKAGE);

    application = boilerplate_application_new ();
    g_application_set_default (G_APPLICATION (application));

    status = g_application_run (G_APPLICATION (application), argc, argv);

    g_object_unref (application);

    return status;
}
